0.1.1 (2022-08-15)
==================

**Fixed**
- Fixed an IndexError when calling `wits.get_tariff_reported` ([#3](https://github.com/mwouts/world_trade_data/issues/3))

**Changed**
- Versions of Python supported are 3.6 to 3.10.


0.1.0 (2019-11-25)
==================

Initial release
